@@ -1,5 +1,9 @@
 test_that("Querying player-level xG values works properly", {
 
+    # TODO: Move all these tests into the API codebase and mock what's below
+    skip_on_cran()
+    skip_on_ci()
+
     # No filters ---------------------------------------------------------
     .obj <- asa_client$get_player_xgoals() %>% nrow()
     expect_gte(.obj, 0)
@@ -220,6 +224,10 @@ test_that("Querying player-level xG values works properly", {
 
 test_that("Querying goalkeeper-level xG values works properly", {
 
+    # TODO: Move all these tests into the API codebase and mock what's below
+    skip_on_cran()
+    skip_on_ci()
+
     # No filters ---------------------------------------------------------
     .obj <- asa_client$get_goalkeeper_xgoals() %>% nrow()
     expect_gte(.obj, 0)
@@ -414,6 +422,10 @@ test_that("Querying goalkeeper-level xG values works properly", {
 
 test_that("Querying team-level xG values works properly", {
 
+    # TODO: Move all these tests into the API codebase and mock what's below
+    skip_on_cran()
+    skip_on_ci()
+
     # No filters ---------------------------------------------------------
     .obj <- asa_client$get_team_xgoals() %>% nrow()
     expect_gte(.obj, 0)
@@ -540,6 +552,10 @@ test_that("Querying team-level xG values works properly", {
 
 test_that("Querying game-level xG values works properly", {
 
+    # TODO: Move all these tests into the API codebase and mock what's below
+    skip_on_cran()
+    skip_on_ci()
+
     # No filters ---------------------------------------------------------
     .obj <- asa_client$get_game_xgoals() %>% nrow()
     expect_gte(.obj, 0)
